############
Installation
############

``python-gitlab`` is compatible with Python 2.7 and 3.4+.

Use :command:`pip` to install the latest stable version of ``python-gitlab``:

.. code-block:: console

   $ sudo pip install --upgrade python-gitlab

The current development version is available on `github
<https://github.com/python-gitlab/python-gitlab>`__. Use :command:`git` and
:command:`python setup.py` to install it:

.. code-block:: console

   $ git clone https://github.com/python-gitlab/python-gitlab
   $ cd python-gitlab
   $ sudo python setup.py install
